==> pandoc-2.14.0.2-2.src.tar.gz: pandoc-2.14.0.2/test/command/6890.md <==
```
% pandoc -t native --citeproc
---
references:
- author:
  - family: Früchtel
    given: Frank
  - family: Budde
    given: Wolfgang
  - family: Cyprian
    given: Gudrun
  edition: 3
  id: fruchtel-sozialer-2013a
  issued: 2013
  language: de-DE
  publisher: Springer VS
  publisher-place: Wiesbaden, Germany
  title: "Sozialer Raum und Soziale Arbeit Fieldbook: Methoden und
    Techniken"
  title-short: Sozialer Raum und Soziale Arbeit Fieldbook
  type: book
---

@fruchtel-sozialer-2013a

Some text [^1].

[^1]: @fruchtel-sozialer-2013a
^D
[Para [Cite [Citation {citationId = "fruchtel-sozialer-2013a", citationPrefix = [], citationSuffix = [], citationMode = AuthorInText, citationNoteNum = 1, citationHash = 0}] [Str "Fr\252chtel,",Space,Str "Budde,",Space,Str "and",Space,Str "Cyprian",Space,Str "(2013)"]]
,Para [Str "Some",Space,Str "text",Str ".",Note [Para [Cite [Citation {citationId = "fruchtel-sozialer-2013a", citationPrefix = [], citationSuffix = [], citationMode = AuthorInText, citationNoteNum = 2, citationHash = 0}] [Str "Fr\252chtel,",Space,Str "Budde,",Space,Str "and",Space,Str "Cyprian",Space,Str "(2013)"]]],Str ""]
,Div ("refs",["references","csl-bib-body","hanging-indent"],[])
 [Div ("ref-fruchtel-sozialer-2013a",["csl-entry"],[])
  [Para [Str "Fr\252chtel,",Space,Str "Frank,",Space,Str "Wolfgang",Space,Str "Budde,",Space,Str "and",Space,Str "Gudrun",Space,Str "Cyprian.",Space,Str "2013.",Space,Emph [Str "Sozialer",Space,Str "Raum",Space,Str "und",Space,Str "Soziale",Space,Str "Arbeit",Space,Str "Fieldbook:",Space,Str "Methoden",Space,Str "und",Space,Str "Techniken"],Str ".",Space,Str "3rd",Space,Str "ed.",Space,Str "Wiesbaden,",Space,Str "Germany:",Space,Str "Springer",Space,Str "VS."]]]]
```

==> pandoc-2.14.1-37.src.tar.gz: pandoc-2.14.1/test/command/6890.md <==
```
% pandoc -t native --citeproc
---
references:
- author:
  - family: Früchtel
    given: Frank
  - family: Budde
    given: Wolfgang
  - family: Cyprian
    given: Gudrun
  edition: 3
  id: fruchtel-sozialer-2013a
  issued: 2013
  language: de-DE
  publisher: Springer VS
  publisher-place: Wiesbaden, Germany
  title: "Sozialer Raum und Soziale Arbeit Fieldbook: Methoden und
    Techniken"
  title-short: Sozialer Raum und Soziale Arbeit Fieldbook
  type: book
---

@fruchtel-sozialer-2013a

Some text.[^1]

[^1]: @fruchtel-sozialer-2013a
^D
[Para [Cite [Citation {citationId = "fruchtel-sozialer-2013a", citationPrefix = [], citationSuffix = [], citationMode = AuthorInText, citationNoteNum = 1, citationHash = 0}] [Str "Fr\252chtel,",Space,Str "Budde,",Space,Str "and",Space,Str "Cyprian",Space,Str "(2013)"]]
,Para [Str "Some",Space,Str "text.",Note [Para [Cite [Citation {citationId = "fruchtel-sozialer-2013a", citationPrefix = [], citationSuffix = [], citationMode = AuthorInText, citationNoteNum = 2, citationHash = 0}] [Str "Fr\252chtel,",Space,Str "Budde,",Space,Str "and",Space,Str "Cyprian",Space,Str "(2013)"]]]]
,Div ("refs",["references","csl-bib-body","hanging-indent"],[])
 [Div ("ref-fruchtel-sozialer-2013a",["csl-entry"],[])
  [Para [Str "Fr\252chtel,",Space,Str "Frank,",Space,Str "Wolfgang",Space,Str "Budde,",Space,Str "and",Space,Str "Gudrun",Space,Str "Cyprian.",Space,Str "2013.",Space,Emph [Str "Sozialer",Space,Str "Raum",Space,Str "und",Space,Str "Soziale",Space,Str "Arbeit",Space,Str "Fieldbook:",Space,Str "Methoden",Space,Str "und",Space,Str "Techniken"],Str ".",Space,Str "3rd",Space,Str "ed.",Space,Str "Wiesbaden,",Space,Str "Germany:",Space,Str "Springer",Space,Str "VS."]]]]
```
